@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,6 +62,10 @@ class FindSubtitlesWindow;
 class VideoPreview;
 #endif
 
+#ifdef USE_SMTUBE_LIB
+class BrowserWindow;
+#endif
+
 class MyAction;
 class MyActionGroup;
 class PreferencesDialog;
@@ -82,7 +86,7 @@ class BaseGui : public QMainWindow
 	Q_OBJECT
 
 public:
-	BaseGui( QWidget* parent = 0, Qt::WindowFlags flags = 0 );
+	BaseGui( QWidget* parent = 0, Qt::WindowFlags flags = QFlag(0) );
 	~BaseGui();
 
 	/* Return true if the window shouldn't show on startup */
@@ -230,6 +234,8 @@ protected slots:
 	virtual void setDefaultValuesFromVideoEqualizer();
 	virtual void changeVideoEqualizerBySoftware(bool b);
 
+	virtual void setSpeed();
+
 	virtual void newMediaLoaded();
 	virtual void updateMediaInfo();
 
@@ -255,6 +261,9 @@ protected slots:
 	void YTUpdate();
 	void YTFailedToStart();
 	void YTUrlNotFound();
+	#ifdef Q_OS_WIN
+	void YTDLLNotFound();
+	#endif
 	#endif
 #endif
 	void gotForbidden();
@@ -486,6 +495,7 @@ protected:
 	MyAction * incSpeed4Act;
 	MyAction * decSpeed1Act;
 	MyAction * incSpeed1Act;
+	QList<MyAction*> speed_acts;
 
 	// Menu Video
 	MyAction * fullscreenAct;
@@ -712,6 +722,7 @@ protected:
 	MyAction * rotateClockwiseAct;
 	MyAction * rotateCounterclockwiseAct;
 	MyAction * rotateCounterclockwiseFlipAct;
+	MyAction * rotate180Act;
 
 	// Menu StayOnTop
 	MyActionGroup * onTopActionGroup;
@@ -905,6 +916,10 @@ protected:
 	int delayed_seek_value;
 #endif
 
+#ifdef USE_SMTUBE_LIB
+	BrowserWindow * browser_window;
+#endif
+
 private:
 	QString default_style;
 
