@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <QCloseEvent>
 #include <QApplication>
 #include <QDesktopWidget>
+#include <QTime>
 
 #ifdef PLAYLIST_DOCKABLE
 #include <QDockWidget>
@@ -96,6 +97,7 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
 	mainwindow_pos = pos();
 
 	quitAct = new MyAction(QKeySequence("Ctrl+Q"), this, "quit");
+	quitAct->setMenuRole(QAction::QuitRole);
 	connect( quitAct, SIGNAL(triggered()), this, SLOT(quit()) );
 
 #ifdef USE_SYSTRAY
@@ -632,7 +634,7 @@ void BaseGuiPlus::aboutToEnterFullscreen() {
 		if ((playlist_screen == mainwindow_screen) /* || 
 	        (!fullscreen_playlist_was_floating) */ ) 
 		{
-			#if QT_VERSION < 0x050000 || !defined(Q_OS_LINUX)
+			#if QT_VERSION < 0x050000 || !defined(OS_UNIX_NOT_MAC)
 			playlistdock->setFloating(true);
 			#endif
 			playlistdock->hide();
@@ -1043,7 +1045,7 @@ void BaseGuiPlus::sendVideoToScreen(int screen) {
 		//is_primary_screen = false;
 		if (is_primary_screen) {
 			mplayerwindow->showNormal();
-			#if QT_VERSION >= 0x050000 && defined(Q_OS_LINUX)
+			#if QT_VERSION >= 0x050000 && defined(OS_UNIX_NOT_MAC)
 			qApp->processEvents();
 			#endif
 			detachVideo(false);
@@ -1089,9 +1091,9 @@ void BaseGuiPlus::detachVideo(bool detach) {
 
 			detached_label->hide();
 
-			mplayerwindow->setWindowTitle(QString::null);
+			mplayerwindow->setWindowTitle(QString());
 			mplayerwindow->setParent(panel);
-			#if QT_VERSION >= 0x050000 && defined(Q_OS_LINUX)
+			#if QT_VERSION >= 0x050000 && defined(OS_UNIX_NOT_MAC)
 			qApp->processEvents();
 			#endif
 			panel->layout()->addWidget(mplayerwindow);
