@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ class BaseGuiPlus : public BaseGui
 	Q_OBJECT
 
 public:
-	BaseGuiPlus( QWidget* parent = 0, Qt::WindowFlags flags = 0);
+	BaseGuiPlus( QWidget* parent = 0, Qt::WindowFlags flags = QFlag(0));
 	~BaseGuiPlus();
 
 	virtual bool startHidden();
