@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -166,7 +166,7 @@ DeviceList DeviceInfo::paDevices() {
 	QStringList env = QProcess::systemEnvironment();
 	env << "LC_ALL=C";
 	p.setEnvironment(env);
-	p.start("pacmd list-sinks");
+	p.start("pacmd list-sinks", QStringList());
 
 	int index = -1;
 	QString name;
@@ -264,7 +264,7 @@ DeviceList DeviceInfo::xvAdaptors() {
 	QProcess p;
 	p.setProcessChannelMode( QProcess::MergedChannels );
 	p.setEnvironment( QProcess::systemEnvironment() << "LC_ALL=C" );
-	p.start("xvinfo");
+	p.start("xvinfo", QStringList());
 
 	if (p.waitForFinished()) {
 		QByteArray line;
