@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -90,7 +90,7 @@ public:
 
 	//! Returns an InfoReader object. If it didn't exist before, one
 	//! is created.
-	static InfoReader * obj(const QString & mplayer_bin = QString::null);
+	static InfoReader * obj(const QString & mplayer_bin = QString());
 
 protected:
 	QString mplayerbin;
