@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -56,19 +56,44 @@ void MplayerProcess::enableScreenshots(const QString & dir, const QString & /* t
 	QString f = "screenshot";
 	if (!dir.isEmpty()) {
 		QString d = QDir::toNativeSeparators(dir);
-		if (MplayerVersion::isMplayerAtLeast(36848)) {
-			f += "="+ d + "/shot";
-		} else {
-			// Keep compatibility with older versions
-			qDebug() << "MplayerProcess::enableScreenshots: this version of mplayer is very old";
-			qDebug() << "MplayerProcess::enableScreenshots: changing working directory to" << d;
-			setWorkingDirectory(d);
-		}
+		f += "="+ d + "/shot";
+		arg << "-vf-add" << f;
 	}
-	arg << "-vf-add" << f;
 }
 
 void MplayerProcess::setOption(const QString & option_name, const QVariant & value) {
+#if defined(USE_COREVIDEO_BUFFER) || defined(USE_SHM)
+	if (option_name == "vo") {
+		QString buffer_name = QString("/smplayer-%1").arg(QCoreApplication::applicationPid());
+		QString vo = value.toString();
+		qDebug() << "MplayerProcess::setOption: vo:" << vo;
+		#ifdef USE_COREVIDEO_BUFFER
+		if (vo.startsWith("corevideo")) {
+			vo = QString("corevideo:buffer_name=%1").arg(buffer_name);
+			arg << "-vo" << vo + ",";
+			arg << "-vf-add" << "format=UYVY";
+			return;
+		}
+		#endif
+		#ifdef USE_SHM
+		if (vo.startsWith("shm")) {
+			vo = QString("shm:buffer_name=%1").arg(buffer_name);
+			arg << "-vo" << vo + ",";
+			return;
+		}
+		#endif
+	}
+	else
+	if (option_name == "wid") {
+		foreach(QString s, arg) {
+			if (s.contains("corevideo") || s.contains("shm")) {
+				qDebug("MplayerProcess::setOption: wid ignored");
+				return;
+			}
+		}
+	}
+#endif
+
 	if (option_name == "ao") {
 		QString ao = value.toString();
 		if (ao.contains(":")) {
@@ -173,6 +198,17 @@ void MplayerProcess::setOption(const QString & option_name, const QVariant & val
 		}
 	}
 	else
+	if (option_name == "channels") {
+		QString v;
+		switch (value.toInt()) {
+			case 2:
+			case 4:
+			case 6:
+			case 8: v = QString::number(value.toInt());
+		}
+		if (!v.isEmpty()) arg << "-channels" << v;
+	}
+	else
 	if (option_name == "keepaspect" ||
 	    option_name == "dr" || option_name == "double" ||
 	    option_name == "fs" || option_name == "slices" ||
@@ -246,6 +282,14 @@ void MplayerProcess::addVF(const QString & filter_name, const QVariant & value)
 		arg << "-vf-add" << "harddup,flip";
 	}
 	else
+	if (filter_name == "rotate") {
+		if (option == "4") {
+			arg << "-vf-add" << "mirror,flip";
+		} else {
+			arg << "-vf-add" << "rotate=" + option;
+		}
+	}
+	else
 	if (filter_name == "letterbox") {
 		QSize desktop_size = value.toSize();
 		double aspect = (double) desktop_size.width() / desktop_size.height();
