@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,6 +53,10 @@
 #include "myscroller.h"
 #endif
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#include <QRandomGenerator>
+#endif
+
 #include "myaction.h"
 #include "mylineedit.h"
 #include "filedialog.h"
@@ -330,9 +334,11 @@ Playlist::Playlist(QWidget * parent, Qt::WindowFlags f)
 	setAcceptDrops(true);
 	setAttribute(Qt::WA_NoMousePropagation);
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
 	// Random seed
 	QTime now = QTime::currentTime();
 	qsrand(now.msec());
+#endif
 
 	//loadSettings();
 
@@ -350,6 +356,15 @@ Playlist::Playlist(QWidget * parent, Qt::WindowFlags f)
 	history_urls = new URLHistory;
 	history_urls->addUrl("http://smplayer.info/sample.m3u8");
 #endif
+
+#ifdef DELAYED_PLAY
+	last_timestamp = 0;
+	play_later.seek = -1;
+	play_later_timer = new QTimer(this);
+	play_later_timer->setInterval(1000);
+	play_later_timer->setSingleShot(true);
+	connect(play_later_timer, SIGNAL(timeout()), this, SLOT(playItemLater()));
+#endif
 }
 
 Playlist::~Playlist() {
@@ -472,6 +487,7 @@ void Playlist::createTable() {
             this, SLOT(itemActivated(const QModelIndex &)) );
 
 	setFilenameColumnVisible(false);
+	setShuffleColumnVisible(false);
 }
 
 void Playlist::createActions() {
@@ -508,8 +524,8 @@ void Playlist::createActions() {
 	repeatAct->setCheckable(true);
 
 	shuffleAct = new MyAction(this, "pl_shuffle", false);
-	shuffleAct->setCheckable(false);
-	connect( shuffleAct, SIGNAL(triggered()), this, SLOT(shuffle()) );
+	shuffleAct->setCheckable(true);
+	connect( shuffleAct, SIGNAL(toggled(bool)), this, SLOT(shuffle(bool)) );
 
 	// Add actions
 	addCurrentAct = new MyAction(this, "pl_add_current", false);
@@ -893,7 +909,7 @@ void Playlist::changeItem(int row, const QString & filename, const QString name,
 }
 */
 
-void Playlist::addItem(QString filename, QString name, double duration, QStringList params, QString video_url, QString icon_url) {
+void Playlist::addItem(QString filename, QString name, double duration, QStringList params, QString video_url, QString icon_url, int shuffle_pos) {
 	//qDebug() << "Playlist::addItem:" << filename;
 
 	#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
@@ -917,6 +933,7 @@ void Playlist::addItem(QString filename, QString name, double duration, QStringL
 	i->setVideoURL(video_url);
 	i->setIconURL(icon_url);
 	i->setPosition(count()+1);
+	i->setShufflePosition(shuffle_pos);
 	table->appendRow(i->items());
 
 	if (findCurrentItem() == -1) setCurrentItem(0);
@@ -1055,6 +1072,7 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 		setPlaylistFilename(file);
 		setModified( false );
 
+		if (shuffleAct->isChecked()) shuffle(true);
 		if (start_play_on_load) startPlay();
 	}
 }
@@ -1110,6 +1128,7 @@ void Playlist::load_pls(QString file) {
 	setPlaylistFilename(file);
 	setModified( false );
 
+	if (shuffleAct->isChecked()) shuffle(true);
 	if (set.status() == QSettings::NoError && start_play_on_load) startPlay();
 }
 
@@ -1152,49 +1171,23 @@ void Playlist::loadXSPF(const QString & filename) {
 		//list();
 		setPlaylistFilename(filename);
 		setModified( false );
+
+		if (shuffleAct->isChecked()) shuffle(true);
 		if (start_play_on_load) startPlay();
 	}
 }
 
 #ifdef YT_PLAYLIST_SUPPORT
-/// youtube list support
-void Playlist::loadYoutubeList(QByteArray & data) {
-	qDebug() << "Playlist::loadYoutubeList:";
-
-	QDomDocument dom_document;
-	bool ok = dom_document.setContent(data);
-	qDebug() << "Playlist::loadYoutubeList: success:" << ok;
-	if (!ok) return;
-
-	QDomNode root = dom_document.documentElement();
-	if (!root.isNull()) {
-		clear();
-
-		QDomNode track = root.firstChildElement("video");
-		while (!track.isNull()) {
-			QString filename;
-			QStringList extra_params;
-
-			QString title = track.firstChildElement("title").text(); // toCDATASection().data();
-			QString video_url = QString("https://www.youtube.com/watch?v=").append(track.firstChildElement("encrypted_id").text().toLatin1());
-			QString icon_url  = track.firstChildElement("thumbnail").text().toLatin1();
-			int duration = track.firstChildElement("length_seconds").text().toInt();
-
-			qDebug() << "Playlist::loadYoutubeList: title:" << title;
-			qDebug() << "Playlist::loadYoutubeList: video_url:" << video_url;
-			qDebug() << "Playlist::loadYoutubeList: icon_url:" << icon_url;
-			qDebug() << "Playlist::loadYoutubeList: duration:" << duration;
-
-			addItem( video_url, title, duration, extra_params, video_url, icon_url );
-
-			track = track.nextSiblingElement("video");
-		}
-
-		//list();
-		setPlaylistFilename(root.firstChildElement("title").text());
-		setModified( false );
-		if (start_play_on_load) startPlay();
+void Playlist::loadYoutubeList(QList<itemMap> list) {
+	qDebug() << "Playlist::loadYoutubeList: list:" << list;
+	clear();
+	foreach(itemMap item, list) {
+		addItem(item["url"], item["title"], item["duration"].toDouble());
 	}
+	setModified( false );
+
+	if (shuffleAct->isChecked()) shuffle(true);
+	if (start_play_on_load) startPlay();
 }
 
 bool Playlist::isYTPlaylist(const QString & url) {
@@ -1560,7 +1553,7 @@ void Playlist::startPlay() {
 	playItem(0);
 }
 
-void Playlist::playItem( int n ) {
+void Playlist::playItem(int n, bool later) {
 	qDebug("Playlist::playItem: %d (count: %d)", n, proxy->rowCount());
 
 	if ( (n >= proxy->rowCount()) || (n < 0) ) {
@@ -1577,12 +1570,30 @@ void Playlist::playItem( int n ) {
 		setCurrentItem(n);
 
 		if (!params.isEmpty()) {
-			emit requestToPlayStream(filename, params);
+			#ifdef DELAYED_PLAY
+			if (later) {
+				play_later.filename = filename;
+				play_later.seek = -1;
+				play_later.params = params;
+				play_later_timer->start();
+			} else
+			#endif
+			{
+				emit requestToPlayStream(filename, params);
+			}
 		} else {
-			if (play_files_from_start) {
-				emit requestToPlayFile(filename, 0);
-			} else {
-				emit requestToPlayFile(filename);
+			int seek = -1;
+			if (play_files_from_start) seek = 0;
+			#ifdef DELAYED_PLAY
+			if (later) {
+				play_later.filename = filename;
+				play_later.seek = seek;
+				play_later.params.clear();
+				play_later_timer->start();
+			} else
+			#endif
+			{
+				emit requestToPlayFile(filename, seek);
 			}
 		}
 	}
@@ -1591,24 +1602,43 @@ void Playlist::playItem( int n ) {
 void Playlist::playNext() {
 	qDebug("Playlist::playNext");
 
+	bool delayed_play = false;
+	#ifdef DELAYED_PLAY
+	qint64 t_now = QDateTime::currentMSecsSinceEpoch();
+	qint64 diff_time = t_now - last_timestamp;
+	if (diff_time < 1000) delayed_play = true;
+	last_timestamp = t_now;
+	//qDebug() << "Playlist::playNext: diff:" << diff_time << "delayed_play:" << delayed_play;
+	#endif
+
 	int current = findCurrentItem();
 	bool finished_list = (current + 1 >= proxy->rowCount());
 	if (finished_list) clearPlayedTag();
 
 	if (repeatAct->isChecked() && finished_list) {
-		playItem(0);
+		playItem(0, delayed_play);
 	} else {
-		playItem(current + 1);
+		playItem(current + 1, delayed_play);
 	}
 }
 
 void Playlist::playPrev() {
 	qDebug("Playlist::playPrev");
+
+	bool delayed_play = false;
+	#ifdef DELAYED_PLAY
+	qint64 t_now = QDateTime::currentMSecsSinceEpoch();
+	qint64 diff_time = t_now - last_timestamp;
+	if (diff_time < 1000) delayed_play = true;
+	last_timestamp = t_now;
+	//qDebug() << "Playlist::playPrev: diff:" << diff_time << "delayed_play:" << delayed_play;
+	#endif
+
 	int current = findCurrentItem() - 1;
 	if (current >= 0) {
-		playItem(current);
+		playItem(current, delayed_play);
 	} else {
-		if (proxy->rowCount() > 1) playItem(proxy->rowCount() - 1);
+		if (proxy->rowCount() > 1) playItem(proxy->rowCount() - 1, delayed_play);
 	}
 }
 
@@ -1621,6 +1651,17 @@ void Playlist::playNextAuto() {
 	}
 }
 
+#ifdef DELAYED_PLAY
+void Playlist::playItemLater() {
+	qDebug() << "Playlist::playItemLater" << play_later.filename << play_later.seek << play_later.params;
+	if (!play_later.params.isEmpty()) {
+		emit requestToPlayStream(play_later.filename, play_later.params);
+	} else {
+		emit requestToPlayFile(play_later.filename, play_later.seek);
+	}
+}
+#endif
+
 void Playlist::resumePlay() {
 	qDebug("Playlist::resumePlay");
 
@@ -1716,8 +1757,14 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 	#endif
 
 	QString initial_file;
-	if (count() == 1) initial_file = itemData(0)->filename();
 	int new_current_item = -1;
+	if (count() == 1) {
+		initial_file = itemData(0)->filename();
+		for (int n = 0; n < files.count(); n++) {
+			if (files[n] == initial_file) new_current_item = n;
+		}
+		if (new_current_item != -1) clear();
+	}
 
 	for (int n = 0; n < files.count(); n++) {
 		QString name = "";
@@ -1733,13 +1780,6 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 
 		//qDebug() << "Playlist::addFiles: comparing:" << initial_file << "with" << files[n];
 
-		if (!initial_file.isEmpty() && files[n] == initial_file) {
-			PLItem * first_item = itemData(0);
-			name = first_item->name();
-			duration = first_item->duration();
-			table->removeRow(0);
-			new_current_item = n;
-		}
 		addItem(files[n], name, duration);
 
 		if (QFile::exists(files[n])) {
@@ -1832,11 +1872,15 @@ void Playlist::removeSelected() {
 	qDebug() << "Playlist::removeSelected: count:" << count;
 	if (count < 1) return;
 
-	for (int n = count; n > 0; n--) {
-		QModelIndex s_index = proxy->mapToSource(indexes.at(n-1));
-		table->removeRow(s_index.row());
-		setModified(true);
+	std::sort(indexes.begin(), indexes.end());
+	for (int n = indexes.count() - 1; n > -1; --n) {
+		QModelIndex s_index = proxy->mapToSource(indexes.at(n));
+		int selected_row = indexes.at(n).row();
+		int actual_row = s_index.row();
+		qDebug() << "Playlist::removeSelected: selected row:" << selected_row << "actual row:" << actual_row;
+		table->removeRow(actual_row);
 	}
+	setModified(true);
 
 	if (isEmpty()) setModified(false);
 
@@ -1858,13 +1902,20 @@ void Playlist::clearPlayedTag() {
 	}
 }
 
-void Playlist::shuffle() {
-	for (int n = 0; n < count(); n++) {
-		PLItem * i = itemData(n);
-		i->setShufflePosition( qrand() % 1000000 );
+void Playlist::shuffle(bool enable) {
+	if (enable) {
+		for (int n = 0; n < count(); n++) {
+			PLItem * i = itemData(n);
+			#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+			i->setShufflePosition( QRandomGenerator::global()->generate() % 1000000 );
+			#else
+			i->setShufflePosition( qrand() % 1000000 );
+			#endif
+		}
+		listView->sortByColumn(COL_SHUFFLE, Qt::AscendingOrder);
+	} else {
+		listView->sortByColumn(COL_NUM, Qt::AscendingOrder);
 	}
-
-	listView->sortByColumn(COL_SHUFFLE, Qt::AscendingOrder);
 }
 
 void Playlist::upItem() {
@@ -2206,7 +2257,7 @@ void Playlist::saveSettings() {
 	set->beginGroup( "playlist");
 
 	set->setValue( "repeat", repeatAct->isChecked() );
-	//set->setValue( "shuffle", shuffleAct->isChecked() );
+	set->setValue( "shuffle", shuffleAct->isChecked() );
 
 	set->setValue( "auto_get_info", automatically_get_info );
 	set->setValue( "recursive_add_directory", recursive_add_directory );
@@ -2259,6 +2310,7 @@ void Playlist::saveSettings() {
 			set->setValue( QString("item_%1_params").arg(n), i->extraParams() );
 			set->setValue( QString("item_%1_video_url").arg(n), i->videoURL() );
 			set->setValue( QString("item_%1_icon_url").arg(n), i->iconURL() );
+			set->setValue( QString("item_%1_shuffle").arg(n), i->shufflePosition() );
 		}
 		set->endArray();
 		set->setValue( "current_item", findCurrentItem() );
@@ -2288,7 +2340,7 @@ void Playlist::loadSettings() {
 	set->beginGroup( "playlist");
 
 	repeatAct->setChecked( set->value( "repeat", repeatAct->isChecked() ).toBool() );
-	//shuffleAct->setChecked( set->value( "shuffle", shuffleAct->isChecked() ).toBool() );
+	shuffleAct->setChecked( set->value( "shuffle", shuffleAct->isChecked() ).toBool() );
 
 	automatically_get_info = set->value( "auto_get_info", automatically_get_info ).toBool();
 	recursive_add_directory = set->value( "recursive_add_directory", recursive_add_directory ).toBool();
@@ -2344,7 +2396,8 @@ void Playlist::loadSettings() {
 			QStringList params = set->value( QString("item_%1_params").arg(n), QStringList()).toStringList();
 			QString video_url = set->value( QString("item_%1_video_url").arg(n), "").toString();
 			QString icon_url = set->value( QString("item_%1_icon_url").arg(n), "").toString();
-			addItem( filename, name, duration, params, video_url, icon_url );
+			int shuffle_pos = set->value( QString("item_%1_shuffle").arg(n), n).toInt();
+			addItem( filename, name, duration, params, video_url, icon_url, shuffle_pos );
 		}
 		set->endArray();
 		setCurrentItem( set->value( "current_item", -1 ).toInt() );
@@ -2457,16 +2510,13 @@ void Playlist::openUrl(const QString & orig_url) {
 	qDebug() << "Playlist::openUrl:" << url;
 
 #ifdef YT_PLAYLIST_SUPPORT
-	// if youtube list then convert to ajax call
 	if (isYTPlaylist(url)) {
-		QUrl qurl = QUrl(url);
-		#if QT_VERSION >= 0x050000
-		QUrlQuery query = QUrlQuery(qurl);
-		QString lst = query.queryItemValue("list"); // QString("RDQ4DphMfcOOM"); // todo
-		#else
-		QString lst = qurl.queryItemValue("list");
-		#endif
-		url = QString("https://www.youtube.com/list_ajax?action_get_list=1&style=xml&list=").append(lst);
+		setCursor(QCursor(Qt::WaitCursor));
+		RetrieveYoutubeUrl yt(this);
+		QList<itemMap> list = yt.getPlaylistItems(url);
+		loadYoutubeList(list);
+		unsetCursor();
+		return;
 	}
 #endif
 
@@ -2484,12 +2534,6 @@ void Playlist::playlistDownloaded(QByteArray data) {
 	QString tfile = tf.fileName();
 	qDebug() << "Playlist::playlistDownloaded: tfile:" << tfile;
 
-#ifdef YT_PLAYLIST_SUPPORT
-	if (data.contains("<?xml")) {
-		loadYoutubeList(data);
-	}
-	else
-#endif
 	if (data.contains("#EXTM3U")) {
 		load_m3u(tfile, M3U8);
 		setPlaylistFilename("");
