@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <QTranslator>
 #include <QLocale>
 #include <QApplication>
+#include <QDebug>
 
 Translator::Translator() {
 	qApp->installTranslator( &app_trans );
@@ -28,6 +29,9 @@ Translator::Translator() {
 	#if QT_VERSION >= 0x050000
 	qApp->installTranslator( &qtbase_trans );
 	#endif
+	#ifdef USE_SMTUBE_LIB
+	qApp->installTranslator( &smtube_trans );
+	#endif
 }
 
 Translator::~Translator() {
@@ -36,39 +40,42 @@ Translator::~Translator() {
 bool Translator::loadCatalog(QTranslator & t, QString name, QString locale, QString dir) {
 	QString s = name + "_" + locale; //.toLower();
 	bool r = t.load(s, dir);
-	if (r) 
-		qDebug("Translator::loadCatalog: successfully loaded %s from %s", s.toUtf8().data(), dir.toUtf8().data());
+	if (r)
+		qDebug() << "Translator::loadCatalog: successfully loaded" << s << "from" << dir;
 	else
-		qDebug("Translator::loadCatalog: can't load %s from %s", s.toUtf8().data(), dir.toUtf8().data());
+		qDebug() << "Translator::loadCatalog: can't load" << s << "from" << dir;
 	return r;
 }
 
 void Translator::load(QString locale) {
-    if (locale.isEmpty()) {
-        locale = QLocale::system().name();
-    }
+	if (locale.isEmpty()) {
+		locale = QLocale::system().name();
+	}
 
 	QString trans_path = Paths::translationPath();
 	QString qt_trans_path = Paths::qtTranslationPath();
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
-	// In windows and OS2 try to load the qt translation from the app path, as
-    // most users won't have Qt installed.
+	// On windows and OS2 try to load the qt translation from the app path, as
+	// most users won't have Qt installed.
 	loadCatalog(qt_trans, "qt", locale, trans_path );
 	#if QT_VERSION >= 0x050000
 	loadCatalog(qtbase_trans, "qtbase", locale, trans_path);
 	#endif
 #else
-	// In linux try to load it first from app path (in case there's an updated
-    // translation), if it fails it will try then from the Qt path.
-	if (! loadCatalog(qt_trans, "qt", locale, trans_path ) ) {
+	// On linux try to load it first from app path (in case there's an updated
+	// translation), if it fails it will try then from the Qt path.
+	if (!loadCatalog(qt_trans, "qt", locale, trans_path ) ) {
 		loadCatalog(qt_trans, "qt", locale, qt_trans_path);
 	}
 	#if QT_VERSION >= 0x050000
-	if (! loadCatalog(qtbase_trans, "qtbase", locale, trans_path ) ) {
+	if (!loadCatalog(qtbase_trans, "qtbase", locale, trans_path ) ) {
 		loadCatalog(qtbase_trans, "qtbase", locale, qt_trans_path);
 	}
 	#endif
 #endif
 	loadCatalog(app_trans, "smplayer", locale, trans_path);
+#ifdef USE_SMTUBE_LIB
+	loadCatalog(smtube_trans, "smtube", locale, trans_path);
+#endif
 }
