@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ protected:
 	void saveSettings();
 	void loadSettings();
 
-#if defined(Q_OS_LINUX) && !defined(NO_SMPLAYER_SUPPORT)
+#if defined(Q_OS_UNIX) && !defined(NO_SMPLAYER_SUPPORT)
 	bool isOptionAvailableinMPV(const QString & option);
 #endif
 
