@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2021 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,11 @@
 class QSettings;
 #endif
 
+//#define YTDL_DEFAULT_BIN "youtube-dl"
+#define YTDL_DEFAULT_BIN "yt-dlp"
+
+typedef QMap<QString, QString> itemMap;
+
 class RetrieveYoutubeUrl : public QObject
 {
 	Q_OBJECT
@@ -106,8 +111,8 @@ public:
 	void enableAv1(bool b) { use_av1 = b; }
 	bool isAv1Enabled() { return use_av1; }
 
-	void setYtdlBin(const QString & path) { ytdl_bin = path; };
-	QString ytdlBin();
+	static void setYtdlBin(const QString & path) { ytdl_bin = path; };
+	static QString ytdlBin();
 
 	void setUserAgent(const QString & s) { user_agent = s; }
 	QString userAgent() { return user_agent; };
@@ -130,6 +135,8 @@ public:
 
 	static QString extensionForItag(int itag);
 
+	QList<itemMap> getPlaylistItems(const QString & url);
+
 #ifdef YT_OBSOLETE
 	#ifdef YT_USE_SIG
 	void setSettings(QSettings * /*settings*/) {};
@@ -148,6 +155,9 @@ signals:
 	void gotEmptyList();
 	void connecting(QString host);
 	void processFailedToStart();
+#ifdef Q_OS_WIN
+	void dllNotFound();
+#endif
 #ifdef YT_OBSOLETE
 	void errorOcurred(int error_number, QString error_str);
 	void signatureNotFound(const QString & title);
@@ -160,10 +170,14 @@ protected slots:
 
 protected:
 	void clearData();
+	QString absoluteFilePath(QString app_bin);
 	void runYtdl(const QString & url);
 	static QString getVideoID(QString video_url);
 	static QString resolutionToText(Resolution r);
 	static int getItagFromFormat(const QByteArray & t);
+#ifndef Q_OS_WIN
+	static QString findExecutable(const QString & name);
+#endif
 
 private:
 	Resolution preferred_resolution;
@@ -189,7 +203,7 @@ private:
 	QString user_format;
 
 	QProcess * process;
-	QString ytdl_bin;
+	static QString ytdl_bin;
 };
 
 #endif
